<?php
/**
 * Aliases for Math
 *
 * In addition to this file, there is Math.alias.noTranslate.php that contains invisible
 * special pages.
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'MathStatus' => array( 'MathStatus' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'MathStatus' => array( 'حالة_الرياضيات' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'MathStatus' => array( 'وضعیت_ریاضی' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'MathStatus' => array( 'МатСтатус' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'MathStatus' => array( '数学状态' ),
);